import { BigNumberish, BytesLike, Signer } from 'ethers';
import { AddressLike } from '@crestproject/crestproject';
import { AdapterBlacklist, AdapterWhitelist, AggregatedDerivativePriceFeed, AssetBlacklist, AssetWhitelist, ChaiAdapter, ChainlinkPriceFeed, ChaiPriceFeed, ComptrollerLib, Engine, EngineAdapter, EntranceRateFee, FeeManager, FundCalculator, FundDeployer, FundLifecycleLib, IntegrationManager, InvestorWhitelist, KyberAdapter, ManagementFee, MaxConcentration, PerformanceFee, PermissionedVaultActionLib, PolicyManager, TrackedAssetsAdapter, ValueInterpreter, VaultLib, ZeroExV2Adapter } from '@melonproject/protocol';
export interface ReleaseDeploymentConfig {
    deployer: Signer;
    dispatcher: AddressLike;
    mgm: AddressLike;
    weth: AddressLike;
    mln: AddressLike;
    registeredVaultCalls: {
        contracts: AddressLike[];
        selectors: BytesLike[];
    };
    engine: {
        thawDelay: BigNumberish;
    };
    integrationManager: {
        trackedAssetsLimit: BigNumberish;
    };
    chainlink: {
        ethUsdAggregator: AddressLike;
        staleRateThreshold: BigNumberish;
        primitives: AddressLike[];
        aggregators: AddressLike[];
        rateAssets: BigNumberish[];
    };
    integratees: {
        chai: AddressLike;
        kyber: AddressLike;
        makerDao: {
            dai: AddressLike;
            pot: AddressLike;
        };
        uniswapV2: {
            factory: AddressLike;
        };
        zeroExV2: {
            exchange: AddressLike;
            erc20Proxy: AddressLike;
        };
    };
}
export interface ReleaseDeploymentOutput {
    comptrollerLib: Promise<ComptrollerLib>;
    fundDeployer: Promise<FundDeployer>;
    fundLifecycleLib: Promise<FundLifecycleLib>;
    permissionedVaultActionLib: Promise<PermissionedVaultActionLib>;
    vaultLib: Promise<VaultLib>;
    engine: Promise<Engine>;
    valueInterpreter: Promise<ValueInterpreter>;
    feeManager: Promise<FeeManager>;
    integrationManager: Promise<IntegrationManager>;
    policyManager: Promise<PolicyManager>;
    chainlinkPriceFeed: Promise<ChainlinkPriceFeed>;
    aggregatedDerivativePriceFeed: Promise<AggregatedDerivativePriceFeed>;
    chaiPriceFeed: Promise<ChaiPriceFeed>;
    chaiAdapter: Promise<ChaiAdapter>;
    engineAdapter: Promise<EngineAdapter>;
    kyberAdapter: Promise<KyberAdapter>;
    trackedAssetsAdapter: Promise<TrackedAssetsAdapter>;
    zeroExV2Adapter: Promise<ZeroExV2Adapter>;
    entranceRateFee: Promise<EntranceRateFee>;
    managementFee: Promise<ManagementFee>;
    performanceFee: Promise<PerformanceFee>;
    adapterBlacklist: Promise<AdapterBlacklist>;
    adapterWhitelist: Promise<AdapterWhitelist>;
    assetBlacklist: Promise<AssetBlacklist>;
    assetWhitelist: Promise<AssetWhitelist>;
    maxConcentration: Promise<MaxConcentration>;
    investorWhitelist: Promise<InvestorWhitelist>;
    fundCalculator: Promise<FundCalculator>;
}
export declare const deployRelease: (config: ReleaseDeploymentConfig) => Promise<import("../utils").Deployment<import("../utils").DeploymentHandlers<ReleaseDeploymentConfig, ReleaseDeploymentOutput>>>;
