import { BigNumber, BigNumberish, Signer, utils, providers } from 'ethers';
import { AddressLike } from '@crestproject/crestproject';
export interface UnsignedZeroExV2Order {
    exchangeAddress: string;
    makerAddress: string;
    takerAddress: string;
    feeRecipientAddress: string;
    senderAddress: string;
    makerAssetAmount: string;
    takerAssetAmount: string;
    makerFee: string;
    takerFee: string;
    expirationTimeSeconds: string;
    salt: string;
    makerAssetData: string;
    takerAssetData: string;
    makerAsset: string;
    takerAsset: string;
}
export interface SignedZeroExV2Order extends UnsignedZeroExV2Order {
    signature: string;
}
export declare function generatePseudoRandomZeroExV2Salt(): BigNumber;
export declare const zeroExV2AssetFragment: utils.FunctionFragment;
export declare function encodeZeroExV2AssetData(tokenAddress: string): string;
export declare function createUnsignedZeroExV2Order({ provider, exchange, maker, feeRecipientAddress, makerAssetAmount, takerAssetAmount, takerFee, duration, makerAsset, takerAsset, }: {
    provider: providers.Provider;
    exchange: AddressLike;
    maker: AddressLike;
    feeRecipientAddress: AddressLike;
    makerAssetAmount: BigNumberish;
    takerAssetAmount: BigNumberish;
    takerFee: BigNumberish;
    duration?: number;
    makerAsset: AddressLike;
    takerAsset: AddressLike;
}): Promise<UnsignedZeroExV2Order>;
export declare function signZeroExV2Order(order: UnsignedZeroExV2Order, signer: Signer): Promise<SignedZeroExV2Order>;
export declare function createZeroExV2OrderTypedData(order: UnsignedZeroExV2Order): import("ethers-eip712").TypedData;
export declare function encodeZeroExV2Order(order: SignedZeroExV2Order): Promise<Uint8Array>;
export declare function zeroExV2TakeOrderArgs(order: SignedZeroExV2Order, takerAssetFillAmount: BigNumberish): Promise<Uint8Array>;
