import { Signer } from 'ethers';
import { AddressLike } from '@crestproject/crestproject';
import { Dispatcher, MockToken, MockChainlinkPriceSource, MockChaiIntegratee, MockKyberIntegratee, MockGenericAdapter, MockGenericIntegratee, WETH, MockChaiPriceSource } from '@melonproject/protocol';
import { Deployment, DeploymentHandlers } from '../utils';
import { ReleaseDeploymentConfig } from './deployment';
export interface MockDeploymentConfig {
    deployer: Signer;
    accounts?: Signer[];
}
export interface MockDeploymentOutput {
    tokens: Promise<{
        weth: WETH;
        mln: MockToken;
        rep: MockToken;
        knc: MockToken;
        zrx: MockToken;
        dai: MockToken;
        ren: MockToken;
    }>;
    kyberIntegratee: Promise<MockKyberIntegratee>;
    chaiIntegratee: Promise<MockChaiIntegratee>;
    mockGenericAdapter: Promise<MockGenericAdapter>;
    mockGenericIntegratee: Promise<MockGenericIntegratee>;
    chainlinkEthUsdAggregator: Promise<MockChainlinkPriceSource>;
    chainlinkAggregators: Promise<{
        mln: MockChainlinkPriceSource;
        rep: MockChainlinkPriceSource;
        knc: MockChainlinkPriceSource;
        zrx: MockChainlinkPriceSource;
        dai: MockChainlinkPriceSource;
        ren: MockChainlinkPriceSource;
    }>;
    chaiPriceSource: Promise<MockChaiPriceSource>;
}
export declare type MockDeployment = Deployment<DeploymentHandlers<MockDeploymentConfig, MockDeploymentOutput>>;
export declare const deployMocks: (config: MockDeploymentConfig) => Promise<Deployment<DeploymentHandlers<MockDeploymentConfig, MockDeploymentOutput>>>;
export declare function configureMockRelease({ deployer, mgm, dispatcher, mocks, accounts, }: {
    deployer: Signer;
    mgm: AddressLike;
    dispatcher: Dispatcher;
    mocks: MockDeployment;
    accounts: Signer[];
}): Promise<ReleaseDeploymentConfig>;
export declare function makeEthRich(sender: Signer, receiver: AddressLike, amount?: import("ethers").BigNumber): Promise<import("@ethersproject/abstract-provider").TransactionResponse>;
export declare function makeWethRich(weth: WETH, account: Signer, amount?: import("ethers").BigNumber): Promise<import("@crestproject/crestproject").ContractReceipt<import("@crestproject/crestproject").SendFunction<[], void, WETH>>>;
export declare function makeTokenRich(tokens: MockToken[], receiver: AddressLike, amount?: import("ethers").BigNumber): Promise<import("@crestproject/crestproject").ContractReceipt<import("@crestproject/crestproject").SendFunction<[_who: AddressLike, _amount: import("ethers").BigNumberish], void, MockToken>>[]>;
