import { BigNumberish, BytesLike, Signer, utils } from 'ethers';
import { AddressLike } from '@crestproject/crestproject';
import { ComptrollerLib, ComptrollerProxy, FundDeployer, VaultLib } from '@melonproject/protocol';
import { BuySharesParams, DenominationAssetInterface } from './shares';
export declare type InitialInvestmentParams = Omit<BuySharesParams, 'comptrollerProxy' | 'denominationAsset'>;
export interface CreateMigratedFundConfigParams {
    signer: Signer;
    fundDeployer: FundDeployer;
    denominationAsset: DenominationAssetInterface;
    sharesActionTimelock?: BigNumberish;
    allowedBuySharesCallers?: AddressLike[];
    feeManagerConfigData?: BytesLike;
    policyManagerConfigData?: BytesLike;
}
export interface CreateNewFundParams {
    signer: Signer;
    fundDeployer: FundDeployer;
    denominationAsset: DenominationAssetInterface;
    sharesActionTimelock?: BigNumberish;
    allowedBuySharesCallers?: AddressLike[];
    fundOwner?: AddressLike;
    fundName?: string;
    feeManagerConfig?: BytesLike;
    policyManagerConfig?: BytesLike;
    investment?: InitialInvestmentParams;
}
export declare function createComptrollerProxy({ signer, comptrollerLib, denominationAsset, sharesActionTimelock, allowedBuySharesCallers, feeManagerConfigData, policyManagerConfigData, }: {
    signer: Signer;
    comptrollerLib: ComptrollerLib;
    denominationAsset: AddressLike;
    sharesActionTimelock?: BigNumberish;
    allowedBuySharesCallers?: AddressLike[];
    feeManagerConfigData?: BytesLike;
    policyManagerConfigData?: BytesLike;
}): Promise<{
    comptrollerProxy: ComptrollerLib;
    deployComptrollerProxyReceipt: import("@crestproject/crestproject").ContractReceipt<import("@crestproject/crestproject").ConstructorFunction<any, ComptrollerProxy>>;
}>;
export declare function createMigratedFundConfig({ signer, fundDeployer, denominationAsset, sharesActionTimelock, allowedBuySharesCallers, feeManagerConfigData, policyManagerConfigData, }: CreateMigratedFundConfigParams): Promise<{
    comptrollerProxy: ComptrollerLib;
    newFundConfigTx: Promise<import("@crestproject/crestproject").ContractReceipt<import("@crestproject/crestproject").SendFunction<[_denominationAsset: AddressLike, _sharesActionTimelock: BigNumberish, _allowedBuySharesCallers: AddressLike[], _feeManagerConfigData: string | utils.Bytes, _policyManagerConfigData: string | utils.Bytes], string, FundDeployer>>>;
}>;
export declare function createNewFund({ signer, fundDeployer, denominationAsset, sharesActionTimelock, allowedBuySharesCallers, fundOwner, fundName, feeManagerConfig, policyManagerConfig, investment, }: CreateNewFundParams): Promise<{
    comptrollerProxy: ComptrollerLib;
    newFundTx: Promise<import("@crestproject/crestproject").ContractReceipt<import("@crestproject/crestproject").SendFunction<[_fundOwner: AddressLike, _fundName: string, _denominationAsset: AddressLike, _sharesActionTimelock: BigNumberish, _allowedBuySharesCallers: AddressLike[], _feeManagerConfigData: string | utils.Bytes, _policyManagerConfigData: string | utils.Bytes], {
        comptrollerProxy_: string;
        vaultProxy_: string;
    }, FundDeployer>>>;
    vaultProxy: VaultLib;
}>;
